@@ -28,6 +28,7 @@ from lakefs_client.model.diff import Diff
 from lakefs_client.model.diff_list import DiffList
 from lakefs_client.model.error import Error
 from lakefs_client.model.forgot_password_request import ForgotPasswordRequest
+from lakefs_client.model.garbage_collection_config import GarbageCollectionConfig
 from lakefs_client.model.garbage_collection_prepare_request import GarbageCollectionPrepareRequest
 from lakefs_client.model.garbage_collection_prepare_response import GarbageCollectionPrepareResponse
 from lakefs_client.model.garbage_collection_rule import GarbageCollectionRule
@@ -47,6 +48,7 @@ from lakefs_client.model.merge_result_summary import MergeResultSummary
 from lakefs_client.model.meta_range_creation import MetaRangeCreation
 from lakefs_client.model.meta_range_creation_response import MetaRangeCreationResponse
 from lakefs_client.model.next_step import NextStep
+from lakefs_client.model.object_copy_creation import ObjectCopyCreation
 from lakefs_client.model.object_error import ObjectError
 from lakefs_client.model.object_error_list import ObjectErrorList
 from lakefs_client.model.object_stage_creation import ObjectStageCreation
@@ -74,6 +76,8 @@ from lakefs_client.model.stage_range_creation import StageRangeCreation
 from lakefs_client.model.staging_location import StagingLocation
 from lakefs_client.model.staging_metadata import StagingMetadata
 from lakefs_client.model.statement import Statement
+from lakefs_client.model.stats_event import StatsEvent
+from lakefs_client.model.stats_events_list import StatsEventsList
 from lakefs_client.model.storage_config import StorageConfig
 from lakefs_client.model.storage_uri import StorageURI
 from lakefs_client.model.tag_creation import TagCreation
